@@ -1,4 +1,7 @@
 package Chart::OFC::Axis;
+BEGIN {
+  $Chart::OFC::Axis::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -51,7 +54,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Base class for axis classes
+
+
 
 =pod
 
@@ -59,6 +64,10 @@ __END__
 
 Chart::OFC::Axis - Base class for axis classes
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class is the base class for the X and Y axis classes. It provides
@@ -108,11 +117,20 @@ This attribute is required.
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
