@@ -1,4 +1,7 @@
 package Chart::OFC::Dataset;
+BEGIN {
+  $Chart::OFC::Dataset::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -66,7 +69,9 @@ __PACKAGE__->meta()->make_immutable();
 1;
 
 
-__END__
+# ABSTRACT: A set of values to be charted
+
+
 
 =pod
 
@@ -74,6 +79,10 @@ __END__
 
 Chart::OFC::Dataset - A set of values to be charted
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $dataset = Chart::OFC::Dataset->new( values => \@numbers );
@@ -105,11 +114,20 @@ links, one per value.
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
