@@ -1,4 +1,7 @@
 package Chart::OFC::Dataset::Area;
+BEGIN {
+  $Chart::OFC::Dataset::Area::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -55,7 +58,9 @@ __PACKAGE__->meta()->make_immutable();
 1;
 
 
-__END__
+# ABSTRACT: A dataset represented as a line with a filled area
+
+
 
 =pod
 
@@ -63,6 +68,10 @@ __END__
 
 Chart::OFC::Dataset::Area - A dataset represented as a line with a filled area
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $bars = Chart::OFC::Dataset::Area->new( values     => \@numbers,
@@ -111,11 +120,20 @@ Defaults to 5.
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
