@@ -1,4 +1,7 @@
 package Chart::OFC::Dataset::Candle;
+BEGIN {
+  $Chart::OFC::Dataset::Candle::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -20,7 +23,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A dataset represented as a candle for each value
+
+
 
 =pod
 
@@ -28,6 +33,10 @@ __END__
 
 Chart::OFC::Dataset::Candle - A dataset represented as a candle for each value
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my @numbers = ( [ 1, 2, 3 ], [ 3, 2, 1 ] );
@@ -58,11 +67,20 @@ that class's attributes. It has no attributes of its own.
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
