@@ -1,4 +1,7 @@
 package Chart::OFC::Dataset::LineWithDots;
+BEGIN {
+  $Chart::OFC::Dataset::LineWithDots::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -46,7 +49,9 @@ __PACKAGE__->meta()->make_immutable();
 1;
 
 
-__END__
+# ABSTRACT: A dataset represented as a line with dots for each value
+
+
 
 =pod
 
@@ -54,6 +59,10 @@ __END__
 
 Chart::OFC::Dataset::LineWithDots - A dataset represented as a line with dots for each value
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $line = Chart::OFC::Dataset::Line->new( values     => \@numbers,
@@ -92,11 +101,20 @@ Defaults to 5.
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
