@@ -1,4 +1,7 @@
 package Chart::OFC::Pie;
+BEGIN {
+  $Chart::OFC::Pie::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -96,7 +99,9 @@ __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: A pie chart
+
+
 
 =pod
 
@@ -104,6 +109,10 @@ __END__
 
 Chart::OFC::Pie - A pie chart
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   my $dataset = Chart::OFC::Dataset->new( values => [ 1 .. 5] );
@@ -166,11 +175,20 @@ Defaults to 80 (percent).
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
