@@ -1,4 +1,7 @@
 package Chart::OFC::Types;
+BEGIN {
+  $Chart::OFC::Types::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -143,7 +146,9 @@ no Moose::Util::TypeConstraints;
 1;
 
 
-__END__
+# ABSTRACT: type library for Chart::OFC
+
+
 
 =pod
 
@@ -151,6 +156,10 @@ __END__
 
 Chart::OFC::Types - type library for Chart::OFC
 
+=head1 VERSION
+
+version 0.10
+
 =head1 SYNOPSIS
 
   package Chart::OFC::Thingy;
@@ -167,11 +176,20 @@ Chart::OFC::Types - type library for Chart::OFC
 This class provides a library of types for use by other Chart::OFC
 classes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
