@@ -1,4 +1,7 @@
 package Chart::OFC::YAxis;
+BEGIN {
+  $Chart::OFC::YAxis::VERSION = '0.10';
+}
 
 use strict;
 use warnings;
@@ -77,7 +80,9 @@ __PACKAGE__->meta()->make_immutable();
 1;
 
 
-__END__
+# ABSTRACT: Y axis for grid charts
+
+
 
 =pod
 
@@ -85,6 +90,10 @@ __END__
 
 Chart::OFC::YAxis - Y axis for grid charts
 
+=head1 VERSION
+
+version 0.10
+
 =head1 DESCRIPTION
 
 This class represents the Y axis for a grid chart.
@@ -136,11 +145,20 @@ defines it, but is consistent with the same attribute for the X axis
 
 This class does the C<Chart::OFC::Role::OFCDataLines> role.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
